=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2007-09-17 22:13:29 +0000
+++ bzrlib/osutils.py	2007-09-20 09:30:39 +0000
@@ -786,15 +786,18 @@
             raise
         shutil.copyfile(src, dest)
 
-def delete_any(full_path):
+
+# Look Before You Leap (LBYL) is appropriate here instead of Easier to Ask for
+# Forgiveness than Permission (EAFP) because:
+# - root can damage a solaris file system by using unlink,
+# - unlink raises different exceptions on different OSes (linux: EISDIR, win32:
+#   EACCES, OSX: EPERM) when invoked on a directory.
+def delete_any(path):
     """Delete a file or directory."""
-    try:
-        os.unlink(full_path)
-    except OSError, e:
-    # We may be renaming a dangling inventory id
-        if e.errno not in (errno.EISDIR, errno.EACCES, errno.EPERM):
-            raise
-        os.rmdir(full_path)
+    if isdir(path): # Takes care of symlinks
+        os.rmdir(path)
+    else:
+        os.unlink(path)
 
 
 def has_symlinks():
@@ -802,7 +805,7 @@
         return True
     else:
         return False
-        
+
 
 def contains_whitespace(s):
     """True if there are any whitespace characters in s."""

=== modified file 'bzrlib/tests/repository_implementations/test_commit_builder.py'
--- bzrlib/tests/repository_implementations/test_commit_builder.py	2007-09-19 01:35:14 +0000
+++ bzrlib/tests/repository_implementations/test_commit_builder.py	2007-09-20 09:30:39 +0000
@@ -420,15 +420,11 @@
         tree = self.make_branch_and_tree('.')
         path = 'name'
         make_before(path)
+
         def change_kind():
-            # Look Before You Leap (LBYL) is appropriate here because unlink
-            # will raise different exceptions on different OSes (linux: EISDIR,
-            # win32: EACCES, OSX: EPERM) when invoked on a directory.
-            if osutils.isdir(path): # Takes care of symlinks
-                os.rmdir(path)
-            else:
-                os.unlink(path)
+            osutils.delete_any(path)
             make_after(path)
+
         self._add_commit_change_check_changed(tree, path, change_kind)
 
     def test_last_modified_dir_file(self):

